@@ -2,6 +2,9 @@ import os
 import json
 import csv
 from pathlib import Path
+
+import openpyxl
+
 from smooth_criminal.core import auto_boost
 from smooth_criminal.memory import export_execution_history, LOG_PATH
 
@@ -9,7 +12,7 @@ from smooth_criminal.memory import export_execution_history, LOG_PATH
 def export_test_func():
     return sum(i for i in range(1000))
 
-def test_export_to_csv_and_json(tmp_path):
+def test_export_to_multiple_formats(tmp_path):
     # Ejecutar función varias veces para llenar historial
     for _ in range(2):
         export_test_func()
@@ -17,6 +20,8 @@ def test_export_to_csv_and_json(tmp_path):
     # Rutas de exportación temporales
     csv_path = tmp_path / "export.csv"
     json_path = tmp_path / "export.json"
+    xlsx_path = tmp_path / "export.xlsx"
+    md_path = tmp_path / "export.md"
 
     # Exportar a CSV
     result_csv = export_execution_history(csv_path, format="csv")
@@ -36,8 +41,26 @@ def test_export_to_csv_and_json(tmp_path):
     assert result_json
     assert json_path.exists()
 
-    # Comprobar contenido del JSON
     with open(json_path, encoding='utf-8') as f:
         data = json.load(f)
         assert isinstance(data, list)
         assert any(entry["function"] == "export_test_func" for entry in data)
+
+    # Exportar a XLSX
+    result_xlsx = export_execution_history(xlsx_path, format="xlsx")
+    assert result_xlsx
+    assert xlsx_path.exists()
+    wb = openpyxl.load_workbook(xlsx_path)
+    ws = wb.active
+    rows = list(ws.iter_rows(values_only=True))
+    assert rows[0][0] == "function"
+    assert any(r[0] == "export_test_func" for r in rows[1:])
+
+    # Exportar a Markdown
+    result_md = export_execution_history(md_path, format="md")
+    assert result_md
+    assert md_path.exists()
+    with open(md_path, encoding="utf-8") as f:
+        content = f.read()
+        assert "export_test_func" in content
+        assert content.startswith("| function |")
